#
# spec file for package quagga
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           quagga
BuildRequires:  net-snmp-devel pam-devel readline-devel
Version:        0.99.23.1
Release:        1.4
PreReq:         %insserv_prereq %fillup_prereq
PreReq:         %install_info_prereq
# pwdutils for useradd and groupadd
PreReq:         pwdutils
Provides:       zebra
Obsoletes:      zebra
AutoReqProv:    on
License:        LGPL v2.1 or later
Group:          Productivity/Networking/Routing
Url:            http://www.quagga.net
Summary:        Free Routing Software (for BGP, OSPF and RIP, for example)
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}-SUSE.tar.bz2
Source2:        quagga.pam
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Quagga is a routing software suite, providing implementations of
OSPFv2, OSPFv3, RIP v1 and v2, RIPv3 and BGPv4 for Unix platforms,
particularly FreeBSD and Linux and also NetBSD, to mention a few.
Quagga is a fork of GNU Zebra which was developed by Kunihiro Ishiguro.
The Quagga tree aims to build a more involved community around Quagga
than the current centralised model of GNU Zebra.



Authors:
--------
    Kunihiro Ishiguro <kunihiro@zebra.org>
    Toshiaki Takada <takada@zebra.org>
    Yasuhiro Ohara <yasu@sfc.wide.ad.jp>
    Alex D. Zinin <azinin@hotmail.com>
    Gleb Natapov <gleb@nbase.co.il>
    Akihiro Mizutani <mizutani@dml.com>

%package      devel
License:        LGPL v2.1 or later
Summary:        Free Routing Software (for BGP, OSPF and RIP, for example)
Requires:       %{name} = %{version}
Group:          Productivity/Networking/Routing

%description devel
Quagga is a routing software suite, providing implementations of
OSPFv2, OSPFv3, RIP v1 and v2, RIPv3 and BGPv4 for Unix platforms,
particularly FreeBSD and Linux and also NetBSD, to mention a few.
Quagga is a fork of GNU Zebra which was developed by Kunihiro Ishiguro.
The Quagga tree aims to build a more involved community around Quagga
than the current centralised model of GNU Zebra.



Authors:
--------
    Kunihiro Ishiguro <kunihiro@zebra.org>
    Toshiaki Takada <takada@zebra.org>
    Yasuhiro Ohara <yasu@sfc.wide.ad.jp>
    Alex D. Zinin <azinin@hotmail.com>
    Gleb Natapov <gleb@nbase.co.il>
    Akihiro Mizutani <mizutani@dml.com>

%prep
%setup -q -a 1

%build
if ! ls /proc/net/{dev,route,snmp} >/dev/null; then
    echo "ERROR: /proc is not mounted" >&2;
    exit 1;
fi
rm -f m4/libtool.m4 m4/lt*.m4
autoreconf --force --install
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure --disable-static --with-pic \
    --enable-vtysh \
    --enable-rtadv \
    --enable-snmp \
    --enable-ipv6 \
    --with-libpam \
    --enable-netlink \
    --sysconfdir=%{_sysconfdir}/quagga \
    --localstatedir=/var/run/quagga \
    --enable-multipath=0
make %{?jobs:-j%jobs}

%install
rm -r doc/quagga.info
make DESTDIR=$RPM_BUILD_ROOT install
rm -rf $RPM_BUILD_ROOT%{_libdir}/lib{ospf,zebra}.la
install -d $RPM_BUILD_ROOT/etc/{init.d,quagga,pam.d,logrotate.d}
install -m 755 SUSE/* $RPM_BUILD_ROOT%{_sysconfdir}/init.d/
install -m 644 %{S:2} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/quagga
install -d -m 750 $RPM_BUILD_ROOT/var/log/quagga
install -d -m 751 $RPM_BUILD_ROOT/var/run/quagga
install -m 644 redhat/quagga.logrotate $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/quagga
ln -sf %{_sysconfdir}/init.d/zebra  $RPM_BUILD_ROOT%{_sbindir}/rczebra
ln -sf %{_sysconfdir}/init.d/bgpd   $RPM_BUILD_ROOT%{_sbindir}/rcbgpd
ln -sf %{_sysconfdir}/init.d/ospf6d $RPM_BUILD_ROOT%{_sbindir}/rcospf6d
ln -sf %{_sysconfdir}/init.d/ospfd  $RPM_BUILD_ROOT%{_sbindir}/rcospfd
ln -sf %{_sysconfdir}/init.d/ripngd $RPM_BUILD_ROOT%{_sbindir}/rcripngd
ln -sf %{_sysconfdir}/init.d/ripd   $RPM_BUILD_ROOT%{_sbindir}/rcripd
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/quagga/*.sample*
cat > $RPM_BUILD_ROOT%{_sysconfdir}/quagga/zebra.conf << __EOF__
hostname quagga
password quagga
enable password quagga
log file /var/log/quagga/quagga.log
__EOF__
touch $RPM_BUILD_ROOT%{_sysconfdir}/quagga/vtysh.conf

%pre
%{_sbindir}/groupadd -r quagga 2> /dev/null || :
%{_sbindir}/useradd -r -g quagga -s %{_bindir}/false \
                  -c "Quagga routing daemon" \
                  -d /var/run/quagga quagga 2> /dev/null || :

%post
/sbin/ldconfig
%fillup_and_insserv
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%stop_on_removal zebra bgpd ospf6d ospfd ripd ripngd

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%restart_on_update zebra bgpd ospf6d ospfd ripd ripngd
%insserv_cleanup
/sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc */*.sample* AUTHORS COPYING* ChangeLog NEWS README REPORTING-BUGS SERVICES TODO
%{_sbindir}/*
%config %{_sysconfdir}/quagga/
%config(noreplace) %{_sysconfdir}/logrotate.d/*
%config %{_sysconfdir}/init.d/*
%config (noreplace)%{_sysconfdir}/pam.d/*
%{_bindir}/*
%dir %attr(-,quagga,quagga) /var/log/quagga
%dir %attr(-,quagga,quagga) /var/run/quagga
%{_infodir}/quagga.info*
%{_mandir}/man?/*
%attr(755,root,root) %{_libdir}/lib*.so.*

%files devel
%defattr(644,root,root,755)
%{_libdir}/*.so
%{_libdir}/*.la
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%dir %{_includedir}/%{name}/ospfd
%{_includedir}/%{name}/ospfd/*.h
%dir %{_includedir}/%{name}/ospfapi
%{_includedir}/%{name}/ospfapi/ospf_apiclient.h
%changelog
* Sat Jan  3 2015 cs@linux-administrator.com
- update to release 0.99.23.1
* Sat Jan 18 2014 cs@linux-administrator.com
- update to release 0.99.22.4
